sqlobject.tests.test_default_style module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_default_style module

Test the default styles, to guarantee consistency.

class `sqlobject.tests.test_default_style.` `DefaultStyleTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = default_style_test
  `q` = default_style_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_default_style.DefaultStyleTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'default_style_test'

`sqlobject.tests.test_default_style.` `do_col_test`(DefaultStyleTest, style, dbnames)

`sqlobject.tests.test_default_style.` `do_fkey_test`(DefaultStyleTest, style, dbname)

`sqlobject.tests.test_default_style.` `make_columns`()

`sqlobject.tests.test_default_style.` `test_default_styles`()